function [yy,uu] = lamperti_invtrans(xx,H,samplingmode,q) ;

% Inverse Lamperti transformation
% [yy,uu] = lamperti_invtrans(xx,H,samplingmode,q) ;
%
% INPUT xx = signal to transform (self-similar world)
%       H = similarity exponent
%       samplingmode = sampling of xx (default 'a', q=1)
%               some vector to specify the sampling instant of yy
%               'a' for arithmetical samplig of yy, with step q (q*(1:N))
%               'g' for geometric sampling (q.^(1:N))
%               'l' for logarihmic sampling (log(q*(1:N))
%  (warning: 'l' is not a logical choice)
%
% OUTPUT yy = Lamperti image of xx
%       uu = sampling times for  yy
%
% (pborgnat 2002)

%definition of sampling
N=length(xx);
if nargin==2,
        samplingmode='a' ; q=1;
end;

if (nargin==3),
if samplingmode=='a', uu=1:N;
elseif samplingmode=='g',
	q=input('Enter the geometric sampling ratio, q = ? ');
	tt=q.^(1:N);
elseif samplingmode=='l', 
	tt=log(1:N); q=[];
elseif (length(samplingmode)>1),
        tt=samplingmode; q=[];
end;
end;

if length(q)==1,
        if samplingmode=='a', tt=q*(1:N); end;
        if samplingmode=='g', tt=q.^(1:N); end;
        if samplingmode=='l', tt=log(q*(1:N)); end;
end;

% tranformation
uu=log(tt);
yy=tt.^(-H).*xx ;


