function [Mellin,beta,Q,Kmin,Nb,Mmin,elog,yyelog]=mellint_inttrans(yy,r,V1);

% Discrete Mellin transform (interactive script)
% [Mellin,beta,Q,Kmin,Nb,Mmin,elog,yyelog]=mellin_inttrans(yy,r,V1);
%
% Algorithm from Bertrand, Bertrand and Ovarlez
% INPUT yy = analysed signal (regular sampling, sampling period set to 1)
%       r = amplitude parameter (take r=-H-1)
%       V1 = time of the 1st sample (yy[1]=signal(V1)) (default=1)
%
% OUTPUT Mellin = discrete Mellin transform of yy
%       beta = Mellin scale variable vector
%       Q = 1/log(Q) is the sampling step for Mellin scale variable
%       Kmin = first index of the sampled beta's
%       Nb = number of points for beta
%       Mmin =  min. index for the geometrical sampling of yy (in q^n)
%       elog = geometrical sampling vector used
%       yyelog = geometrically resampled yy
%
% This is an interactive version of Mellin transform for the choice
% of the number and range of beta samples. 
% Note that the signal (in yyelog) is completed by
% zero-padding if the required sampling leaves the
% interval of definition of yy, assumed to be [V1:V1+length(yy)-1]
%
% Example:
% [mellin,beta,Q,K,Nb,M]=mellin_inttrans(yy,r,1) ;
%
% pborgnat (february 2000)
%


%% Transformee de Mellin discrete, version interactive
%Algorithme selon Bertrand et al.
%INPUT: yy = signal a analyser
%       r = parametre du groupe de dilatation
%       V1 = debut du signal echantillonne fourni (yy[1] = signal(V1))
%OUTPUT: Mellin = transf de Mellin discrete
%        beta = variable de Mellin echantillonnee
%        Q = rapport de periodisation par dilatation ; pas en Mellin =  1/ln(Q)
%        Kmin = indice min des beta echantillonnes
%        Nb = nombre de points en beta
%        Mmin = indice min de l'echantillonnage log (en q^n)
%        elog = vecteur des Nb pts d'echantillonnage log  
%
% Choix interactif des bornes et pas d'echantillonnage en Mellin ;
%Signal analyse reellement en entree (on ne rajoute pas de zeros)
%Convention : echantillon 1 = valeur au temps V1.
%
%exemple : [mellin,beta,Q,K,Nb,M]=mellint_int(yy,r,1) ;
%
%(pborgnat fevrier 2000)

hold off ;
[yrow,ycol] = size(yy) ;
if yrow ~= 1, yy = yy' ; end ;
N = length(yy) ;
%% N est le nbre de points en temps du signal entre %%

%% Choix des parametres d'echantillonnage

%% procedure pour trouver [F1 F2] support de YY... => DF %%
%% et [V1 V2] support de yy... => Q_min %%
%approche simplifiee ; on utilise la variable temporelle v = t/\tau_e 
%V1 = 1 ;
V0 = 1-V1 ; %indice, evt non entier, de la position du zero en temps.
txtNy = ['Do you want to choose V2 and Q ? (y/n)'] ; 
askNy = input(txtNy,'s') ;
if (~isempty(askNy))&(askNy=='y'),
  disp(['Correct Sampling between V1 and V2 => Q=V2/V1, here V1=',num2str(V1)]) ; 
  plot(abs(yy),'.-') ; hold on ; plot(real(yy),'--') ;
  xlabel('Sample indice') ;
  axis([V0 N 0 max(abs(yy))]) ; grid ; hold off ;
  txtinputNy = ['Number of points used (V2-V1+1) ? [',num2str(N),'] :'] ;
  Ny = input(txtinputNy) ;
  if isempty(Ny), Ny = N; end;
else,
  Ny = N ;
end ;
% Ny nbre de points utilises dans l'analyse 
V2 = Ny+V1-1 ; %borne max du support temporel ;
Ny2 = Ny ;  %longueur du signal unilateral a analyser ;
%pour un signal unilateral => borne max temporelle du signal a analyser =
%V2 = Ny2+V1-1 ;
Q = V2/V1 ;
disp(['Q=',num2str(Q),' and sampling period in Mellin domain = ',num2str(1/log(Q))]) ;

if (Ny>N), yy(N+1:Ny) = zeros(1,Ny-N) ; end
fyy = yy(1:Ny) ;
%fyy = [yy(1:Ny) zeros(1,Ny)] ;
% interpretation freq. : prendre fftshift(fyy) %%
% interpretation temporelle : on rajoute des 0 aux temps negatifs => unilateral %%
YY = ifft(fyy)*Ny2 ;
%% YY est analytique et fft(fyy) = Ny2*fliplr(YY)([Ny2 1:Ny2-1]) %%
%% inversement : FT(YY) = [zeros(1,V2) yy] *Ny2 ;

%choix de DF
fmin=0. ; fmax=0.5 ;
txtDFint = ['Do you want to choose DF ? (y/n)'] ;
DFint = input(txtDFint,'s') ;
if ~isempty(DFint),
if DFint=='y',
F = linspace(-0.5,0.5,Ny2) ;
sp = abs((YY)) ; Maxsp = max(sp) ;  % ou fliplr de YY ??
plot(F,fftshift(fliplr(sp))) ;
xlabel('Normalized frequency') ;
 indmin=min(find(sp>Maxsp/1000));
 indmax=max(find(sp>Maxsp/1000));       
 fmindflt=max([-0.5 0.05*fix(F(indmin)/0.05)]);
 fmaxdflt=0.05*ceil(F(indmax)/0.05); 
 txtmin=['Lower frequency bound [',num2str(fmindflt),'] : '];
 txtmax=['Upper frequency bound [',num2str(fmaxdflt),'] : '];
 fmin = input(txtmin); fmax = input(txtmax);
 if isempty(fmin), fmin=fmindflt; end
 if isempty(fmax), fmax=fmaxdflt; end
end ; end ;
DF = fmax-fmin ;

%Q_min = V2/V1 ;
Nb_min = fix(V2*DF*log(Q)) ;
 %% condition de bon echantillonnage pour Mellin discrete
Nbsp = 2^nextpow2(Nb_min) ;
%% proposer choix de Nb
%txtQ = ['Q ? (step for beta sampling) >=',num2str(Q_min),' [',num2str(Q_min),'] :'] ;
txtNb = ['Nb ? (number of beta samples) >=',num2str(Nb_min),' [',num2str(Nbsp),'] :'] ;
%Q = input(txtQ) ;
Nb = input(txtNb) ;
if isempty(Nb), Nb=Nbsp ; end ;
%if isempty(Q), Q=Q_min; end ;

% d'ou les parametres d'echantillonnage
beta0 = Nb/2/log(Q) ;
q = Q.^(1./Nb) ;  %% NE PAS UTILISER ; PB d'arrondi numerique !!!
logq = log(Q)/Nb ;
Mmin = ceil(log(V1)/logq) ;

%% echantillonnage logarithmique en q^n
nn = (1:Nb) + Mmin-1 ;
elog = exp(logq.*nn) ; % instants q^nn 

% methode par interpolation
eind_sup=ceil(elog-V1+1);   %indices
eind_inf=fix(elog-V1+1);
einf = fix(elog);  %vrai instant

yyelog=(fyy(eind_sup)-fyy(eind_inf)).*(elog-einf)+fyy(eind_inf);
       
% methode par reconstruction en Fourier... (a faire) 

%%echantillonnage lineaire en beta
Kmin = ceil(-beta0*log(Q)) ;
k = (0:Nb-1) + Kmin*ones(1,Nb) ;
beta = k/log(Q) ;

%% transformee discrete de mellin
mm=1:Nb ;
ampl = (r+1)*logq ;
cor_phase = (2*pi*i*Kmin/Nb) ;
blah = exp(mm*(cor_phase+ ampl)-cor_phase).*yyelog ;
TFblah = Nb*logq*exp((Mmin-1)*ampl)*(ifft(blah)) ;
Mellin = TFblah.*exp(2*pi*i*Mmin*k/Nb) ; 


%% Verifier la normalisation
V = linspace(V1,V1+Ny-1,Ny) ;
expnorm = 2*r+1 ;
normR_sig2 = (fyy)*(fyy.*V.^expnorm)' ;
Mellin = sqrt(normR_sig2)*logq*sqrt(log(Q))/norm(Mellin)*Mellin ;


