function [yye,elog] = mellin_invtrans(Mellin,r,Q,K,Nb,M,Ny) ;

% Discrete Inverse Mellin Trannsform
% [yye,elog,yy] = mellin_invtrans(Mellin,r,Q,K,Nb,M,Ny) ;
%
% INPUT	Mellin = a Mellin transform
%	r = amplitude parameter (take r=-H-1)
%	Q = 1/log(Q) is the sampling step for Mellin scale variable
%	K = first index of the sampled beta's
%	Nb = number of points for beta
%	M =  min. index for the geometrical sampling of yy (in q^n)
%	Ny = number of points for arithmetic sampling interpolation (opt.)
%
% OUTPUT yye = geometrically sampled  signal
% 	elog = geometrical sampling vector
%	yy = arithmetically sampled interpolated signal
%
% Example:
% [yye,elog] = mellin_invtrans(mellin,r,Q,K,Nb,M) ;
%
% pborgnat (february 2000)
%

% transformee de mellin discrete inverse
%INPUT: Mellin = tmellin du signal
%       r = parametre du groupe de dilatation
%       Q = donne le pas d'echantillonage   (1/ln(Q))      }
%       K = indice du 1er echantillon en beta }<=> connaissance du vecteur des beta
%       Nb = nombre de points en beta         }
%       M = indice du 1er echantillon en temps => connaissance de V1 et V2 ;
%       Ny = nombre de points pour reconstruction ech. lineaire du signal (optionnel)
%
%OUTPUT yye = signal echantillonne logarithmiquement
%       elog = echnatillonnage log.
%       yy = signal echantillonne lineairement
%
%exemple: [yye,elog] = mellin_invtrans(mellin,r,Q,K,Nb,M) ;
%      
%(pborgnat fevrier 2000)

% indices utiles :
ii = 1:Nb ;
mm = 1:Nb ;
n = mm+M-1 ;
k = ii+K-1 ;

% echantillonnage :
logq = log(Q)/Nb ;
elog = exp(logq*n) ;
V1 = exp(M*logq) ;
V2 = Q*V1 ;
if nargin==7, 
  elin = linspace(V1,V2,Ny) ;
end;

%TMd inverse
ampl = (r+1)*logq ;
cor_phase = -2*i*pi*M/Nb ;
interMellin = Mellin.* exp(cor_phase*(ii-1)) ;
sig_int = (fft(interMellin)) ;
cor_phase2 = -2*i*pi*K/Nb ;
sig_int2 = sig_int.*exp((cor_phase2-ampl)*n) ;
yye = (sig_int2)/log(Q) ;

%normalisation ?
%V = linspace(V1,V2,Ny) ;
diffelog = [diff(elog) 0] ;
expnorm = 2*r+1 ; 
NormR_sig2 = (yye)*(yye.*diffelog.*elog.^expnorm)' ;
Norm_mel2 = norm(Mellin)^2/log(Q)/(logq^2) ;
yye = yye*sqrt(Norm_mel2/NormR_sig2) ;

%normR_sig2 = conj(yye)*(yye.*diffelog.*elog.^expnorm)' ;
%yye = sqrt(logq/normR_sig2)*norm(Mellin)*yye ;

%echantillonnage lineaire....;
% utiliser sampling_change.m





